==> apeman-srch-1.0.2.tgz: package/lib/logging/srch_logger.js <==
/**
 * Logger for search.
 * @constructor SrchLogger
 * @returns A logger instance.
 */

"use strict";

var colorprint = require('colorprint'),
    yaml = require('js-yaml'),
    textconv = require('textconv'),
    clc = require('cli-color');

/** @lends SrchLogger */
module.exports = colorprint.define(
    /** @lends SrchLogger.prototype */
    {
        logSearchStart: function () {
            var s = this;
            s.info('Searching modules...');
        },
        logSearchDone: function () {
            var s = this;
            s.info('...search done!');
        },
        logSearched: function (serched, terms) {
            var s = this;
            s.debug('');
            if (terms.length > 0) {
                s.debug('  Terms: %s', clc.blue.italic(terms.join(', ')));
            }
            s.debug('  Searched modules:');
            s.debug('');
            var NAME_MIN_LENGTH = 24;
            serched
                .filter(function (searched) {
                    return searched.hit;
                })
                .forEach(function (serched) {
                    var term = serched.hitTerm;
                    var name = textconv.pad(serched.name, NAME_MIN_LENGTH);
                    var desc = serched.description;
                    if (term) {
                        name = s._highlight(name, term);
                        desc = s._highlight(desc, term);
                    }
                    s.debug("    %s%s",
                        clc.black.bold(name),
                        clc.blackBright(desc)
                    );
                });
            s.debug('');
            s.debug('');
        },
        _highlight: function (text, keyword) {
            return text.replace(new RegExp(keyword, "g"), function (keyword) {
                return clc.blue.bold(keyword);
            });
        }
    }
);

==> apeman-srch-1.1.0.tgz: package/lib/logging/srch_logger.js <==
/**
 * Logger for search.
 * @constructor SrchLogger
 * @returns A logger instance.
 */

"use strict";

var colorprint = require('colorprint'),
    textconv = require('textconv'),
    colors = colorprint.colors;

/** @lends SrchLogger */
module.exports = colorprint.define(
    /** @lends SrchLogger.prototype */
    {
        logSearchStart: function () {
            var s = this;
            s.info('Searching modules...');
        },
        logSearchDone: function () {
            var s = this;
            s.info('...search done!');
        },
        logSearched: function (serched, terms) {
            var s = this;
            s.debug('');
            if (terms.length > 0) {
                s.debug('  Terms: %s', colors.blue.italic(terms.join(', ')));
            }
            s.debug('  Searched modules:');
            s.debug('');
            var NAME_MIN_LENGTH = 24;
            serched
                .filter(function (searched) {
                    return searched.hit;
                })
                .forEach(function (serched) {
                    var term = serched.hitTerm;
                    var name = textconv.pad(serched.name, NAME_MIN_LENGTH);
                    var desc = serched.description;
                    if (term) {
                        name = s._highlight(name, term);
                        desc = s._highlight(desc, term);
                    }
                    s.debug("    %s%s",
                        colors.black.bold(name),
                        colors.blackBright(desc)
                    );
                });
            s.debug('');
            s.debug('');
        },
        _highlight: function (text, keyword) {
            return text.replace(new RegExp(keyword, "g"), function (keyword) {
                return colors.blue.bold(keyword);
            });
        }
    }
);
